"""Contains all the data models used in inputs/outputs"""

from .agent_bootstrap import AgentBootstrap
from .agent_chat_message_request import AgentChatMessageRequest
from .agent_view_type import AgentViewType
from .blog_post_create_req import BlogPostCreateReq
from .blog_post_create_res import BlogPostCreateRes
from .blog_post_detail_response import BlogPostDetailResponse
from .blog_post_item import BlogPostItem
from .blog_post_list_response import BlogPostListResponse
from .blog_post_update_req import BlogPostUpdateReq
from .blog_post_update_res import BlogPostUpdateRes
from .body_auth_login_access_token import BodyAuthLoginAccessToken
from .bot_config import BotConfig
from .chat_messages_item import ChatMessagesItem
from .chat_messages_item_artifacts_type_0_item import ChatMessagesItemArtifactsType0Item
from .chat_messages_item_props_type_0 import ChatMessagesItemPropsType0
from .chat_messages_response import ChatMessagesResponse
from .common_form_data import CommonFormData
from .common_form_field import CommonFormField
from .doc_coll_create import DocCollCreate
from .doc_coll_public import DocCollPublic
from .doc_colls_public import DocCollsPublic
from .get_threads_request import GetThreadsRequest
from .http_validation_error import HTTPValidationError
from .message import Message
from .new_password import NewPassword
from .pagination import Pagination
from .read_file_req import ReadFileReq
from .run_bash_req import RunBashReq
from .task_form_request import TaskFormRequest
from .task_form_response import TaskFormResponse
from .text_2_image_request import Text2ImageRequest
from .theme import Theme
from .thread_filter import ThreadFilter
from .thread_filter_feedback_type_0 import ThreadFilterFeedbackType0
from .token import Token
from .ui_messages_item import UiMessagesItem
from .ui_messages_item_artifacts_type_0_item import UiMessagesItemArtifactsType0Item
from .ui_messages_item_props_type_0 import UiMessagesItemPropsType0
from .ui_messages_request import UiMessagesRequest
from .ui_messages_response import UiMessagesResponse
from .update_password import UpdatePassword
from .user_register import UserRegister
from .user_update_me import UserUpdateMe
from .validation_error import ValidationError
from .workspace import Workspace

__all__ = (
    "AgentBootstrap",
    "AgentChatMessageRequest",
    "AgentViewType",
    "BlogPostCreateReq",
    "BlogPostCreateRes",
    "BlogPostDetailResponse",
    "BlogPostItem",
    "BlogPostListResponse",
    "BlogPostUpdateReq",
    "BlogPostUpdateRes",
    "BodyAuthLoginAccessToken",
    "BotConfig",
    "ChatMessagesItem",
    "ChatMessagesItemArtifactsType0Item",
    "ChatMessagesItemPropsType0",
    "ChatMessagesResponse",
    "CommonFormData",
    "CommonFormField",
    "DocCollCreate",
    "DocCollPublic",
    "DocCollsPublic",
    "GetThreadsRequest",
    "HTTPValidationError",
    "Message",
    "NewPassword",
    "Pagination",
    "ReadFileReq",
    "RunBashReq",
    "TaskFormRequest",
    "TaskFormResponse",
    "Text2ImageRequest",
    "Theme",
    "ThreadFilter",
    "ThreadFilterFeedbackType0",
    "Token",
    "UiMessagesItem",
    "UiMessagesItemArtifactsType0Item",
    "UiMessagesItemPropsType0",
    "UiMessagesRequest",
    "UiMessagesResponse",
    "UpdatePassword",
    "UserRegister",
    "UserUpdateMe",
    "ValidationError",
    "Workspace",
)



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="CommonFormField")


@_attrs_define
class CommonFormField:
    """
    Attributes:
        name (str):
        label (Union[None, Unset, str]):
        type (Union[None, Unset, str]):
        required (Union[None, Unset, bool]):
        default (Union[None, Unset, str]):
        description (Union[None, Unset, str]):
        options (Union[List[str], None, Unset]):
        placeholder (Union[None, Unset, str]):
    """

    name: str
    label: Union[None, Unset, str] = UNSET
    type: Union[None, Unset, str] = UNSET
    required: Union[None, Unset, bool] = UNSET
    default: Union[None, Unset, str] = UNSET
    description: Union[None, Unset, str] = UNSET
    options: Union[List[str], None, Unset] = UNSET
    placeholder: Union[None, Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name

        label: Union[None, Unset, str]
        if isinstance(self.label, Unset):
            label = UNSET
        else:
            label = self.label

        type: Union[None, Unset, str]
        if isinstance(self.type, Unset):
            type = UNSET
        else:
            type = self.type

        required: Union[None, Unset, bool]
        if isinstance(self.required, Unset):
            required = UNSET
        else:
            required = self.required

        default: Union[None, Unset, str]
        if isinstance(self.default, Unset):
            default = UNSET
        else:
            default = self.default

        description: Union[None, Unset, str]
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        options: Union[List[str], None, Unset]
        if isinstance(self.options, Unset):
            options = UNSET
        elif isinstance(self.options, list):
            options = self.options

        else:
            options = self.options

        placeholder: Union[None, Unset, str]
        if isinstance(self.placeholder, Unset):
            placeholder = UNSET
        else:
            placeholder = self.placeholder

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
            }
        )
        if label is not UNSET:
            field_dict["label"] = label
        if type is not UNSET:
            field_dict["type"] = type
        if required is not UNSET:
            field_dict["required"] = required
        if default is not UNSET:
            field_dict["default"] = default
        if description is not UNSET:
            field_dict["description"] = description
        if options is not UNSET:
            field_dict["options"] = options
        if placeholder is not UNSET:
            field_dict["placeholder"] = placeholder

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        def _parse_label(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        label = _parse_label(d.pop("label", UNSET))

        def _parse_type(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        type = _parse_type(d.pop("type", UNSET))

        def _parse_required(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        required = _parse_required(d.pop("required", UNSET))

        def _parse_default(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        default = _parse_default(d.pop("default", UNSET))

        def _parse_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        description = _parse_description(d.pop("description", UNSET))

        def _parse_options(data: object) -> Union[List[str], None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                options_type_0 = cast(List[str], data)

                return options_type_0
            except:  # noqa: E722
                pass
            return cast(Union[List[str], None, Unset], data)

        options = _parse_options(d.pop("options", UNSET))

        def _parse_placeholder(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        placeholder = _parse_placeholder(d.pop("placeholder", UNSET))

        common_form_field = cls(
            name=name,
            label=label,
            type=type,
            required=required,
            default=default,
            description=description,
            options=options,
            placeholder=placeholder,
        )

        common_form_field.additional_properties = d
        return common_form_field

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.agent_view_type import AgentViewType
from ..types import UNSET, Unset

T = TypeVar("T", bound="AgentBootstrap")


@_attrs_define
class AgentBootstrap:
    """前端获取 agent 的配置
    前端全局agent 加载器会在所有页面加载时返回配置初始化agent UI

        Attributes:
            view_type (Union[AgentViewType, None, Unset]):  Default: AgentViewType.SIDEBAR.
            is_show_fab (Union[Unset, bool]):  Default: True.
    """

    view_type: Union[AgentViewType, None, Unset] = AgentViewType.SIDEBAR
    is_show_fab: Union[Unset, bool] = True
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        view_type: Union[None, Unset, str]
        if isinstance(self.view_type, Unset):
            view_type = UNSET
        elif isinstance(self.view_type, AgentViewType):
            view_type = self.view_type.value
        else:
            view_type = self.view_type

        is_show_fab = self.is_show_fab

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if view_type is not UNSET:
            field_dict["view_type"] = view_type
        if is_show_fab is not UNSET:
            field_dict["is_show_fab"] = is_show_fab

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()

        def _parse_view_type(data: object) -> Union[AgentViewType, None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                view_type_type_0 = AgentViewType(data)

                return view_type_type_0
            except:  # noqa: E722
                pass
            return cast(Union[AgentViewType, None, Unset], data)

        view_type = _parse_view_type(d.pop("view_type", UNSET))

        is_show_fab = d.pop("is_show_fab", UNSET)

        agent_bootstrap = cls(
            view_type=view_type,
            is_show_fab=is_show_fab,
        )

        agent_bootstrap.additional_properties = d
        return agent_bootstrap

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
